==============
Basic Geometry
==============

The basic geometry commands create geometric entities that are referenced by Part objects, Instance objects, and GeometrySet objects.

Classes
-------

Cell
~~~~

.. autoclass:: abaqus.BasicGeometry.Cell.Cell
    :members:
    :special-members: __init__

    .. autoclasstoc::

CellArray
~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.CellArray.CellArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

Edge
~~~~

.. autoclass:: abaqus.BasicGeometry.Edge.Edge
    :members:
    :special-members: __init__

    .. autoclasstoc::

EdgeArray
~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.EdgeArray.EdgeArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

Face
~~~~

.. autoclass:: abaqus.BasicGeometry.Face.Face
    :members:
    :special-members: __init__

    .. autoclasstoc::

FaceArray
~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.FaceArray.FaceArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

IgnoredEdge
~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.IgnoredEdge.IgnoredEdge
    :members:
    :special-members: __init__

    .. autoclasstoc::

IgnoredEdgeArray
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.IgnoredEdgeArray.IgnoredEdgeArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

IgnoredVertex
~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.IgnoredVertex.IgnoredVertex
    :members:
    :special-members: __init__

    .. autoclasstoc::

IgnoredVertexArray
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.IgnoredVertexArray.IgnoredVertexArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

InterestingPoint
~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.InterestingPoint.InterestingPoint
    :members:
    :special-members: __init__

    .. autoclasstoc::

ModelDot
~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.ModelDot.ModelDot
    :members:
    :special-members: __init__

    .. autoclasstoc::

ModelDotArray
~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.ModelDotArray.ModelDotArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

ReferencePoint
~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.ReferencePoint.ReferencePoint
    :members:
    :special-members: __init__

    .. autoclasstoc::

ReferencePointArray
~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.ReferencePointArray.ReferencePointArray
    :members:
    :special-members: __init__

    .. autoclasstoc::

ReferencePoints
~~~~~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.ReferencePoints.ReferencePoints
    :members:
    :special-members: __init__

    .. autoclasstoc::

Transform
~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.Transform.Transform
    :members:
    :special-members: __init__

    .. autoclasstoc::

Vertex
~~~~~~

.. autoclass:: abaqus.BasicGeometry.Vertex.Vertex
    :members:
    :special-members: __init__

    .. autoclasstoc::

VertexArray
~~~~~~~~~~~

.. autoclass:: abaqus.BasicGeometry.VertexArray.VertexArray
    :members:
    :special-members: __init__

    .. autoclasstoc::
